/* create.sql */

create table dictionary (
    type_id hex32 primary key,
    name    string not null
);

create table inventory (
    obj_id  hex64 primary key,                             /* Read-only UID. */
    type_id hex32 references dictionary on delete cascade  /* User data.     */
);

create table recipes (
    name string primary key,
    desc string,
    text string
);

create table ingredients (
    recipe  string references recipes on delete cascade,
    type_id hex32 references dictionary on delete cascade,
    sort    integer,
    qty     string,
    text    string,
    primary key (recipe, type_id),
    unique      (recipe, sort   )
);

insert into dictionary values("00000001", "Kellogg's Corn Flakes");
insert into dictionary values("00000002", "A-1 Steak Sauce"      );
insert into dictionary values("00000003", "Whole Kernel Corn"    );
insert into dictionary values("00000004", "Orange Juice"         );
insert into dictionary values("00000005", "Flour"                );
insert into dictionary values("00000006", "Bread"                );
insert into dictionary values("00000007", "Peanut Butter"        );
insert into dictionary values("00000008", "Jelly"                );

/* Stock the shelves. */
insert into inventory values("0000123741987211", "00000001");
insert into inventory values("0013847938411910", "00000002");
insert into inventory values("9991324872348100", "00000003");
insert into inventory values("0000000112310000", "00000003");
insert into inventory values("0000559123491000", "00000003");

/* Create some recipes. */
/* TODO:
 * - Find some *real* recipes!
 * - Also real ingredients.
 * - Buy them, too, so they can be placed on the shelf in the demo. */
insert into recipes     values("Icky Mess", "Best avoided.",
"Just mix it all together.  Easy to make in a hurry.");
insert into ingredients values("Icky Mess", 29148450, 0, "1 box",      null);
insert into ingredients values("Icky Mess", 29148451, 1, "0.5 bottle", null);
insert into ingredients values("Icky Mess", 29148452, 2, "1 can",      null);

insert into recipes     values("Steak Disaster", "You have been warned.",
"Pour one into the other, then (recommended) pour the result down the drain.");
insert into ingredients values("Steak Disaster", 29148451, 0, "2 bottles",null);
insert into ingredients values("Steak Disaster", 29148453, 1, "1 gallon", null);

insert into recipes     values("PB&J", "Yum.",
"Using a butter knife, spread the peanut butter and jelly on separate slices of
bread, then press the bread slices together, mating condiments.  Serve with
smile.");
insert into ingredients values("PB&J", 29148455, 0, "2 slices", null);
insert into ingredients values("PB&J", 29148456, 1, null, null);
insert into ingredients values("PB&J", 29148457, 2, null, null);

/* vim: set ts=4 sts=4 sw=4 tw=80 et: */
/* EOF */
