/* ss-core/com/stdinout.c
 *
 * Connects a device to stdin/stdout.  Very simple.
 *
 * Copyright (C) 2003, 2004
 * Zorica Majdov <zmajdov@virtuoso.com>
 * Andy Goth     <unununium@openverse.com>
 *
 * This code is available under the GNU General Public License; see COPYING. */

/* === Header files. ====================================================== */

#include <unistd.h>

#include "ss-core/com/stdinout.h"
#include "ss-core/lib/device.h"

/* === Type definitions, static variables, and static prototypes. ========= */

/* Closes previously-opened device 'd' connected to stdin/stdout. */
static int stdinout_close(device_t* d);

/* === Non-static function definitions. =================================== */

/* Connects device 'd' to stdin and stdout. */
int stdinout_open(device_t* d)
{
    if (d == NULL) return -1;
    device_connect_fd(d, STDIN_FILENO, STDOUT_FILENO);
    d->on_cleanup_com = stdinout_close;
    return 0;
}

/* === Static function definitions. ======================================= */

/* Closes previously-opened device 'd' connected to stdin/stdout. */
static int stdinout_close(device_t* d)
{
    if (d == NULL) return -1;
    device_connect_fd(d, -1, -1);
    return 0;
}

/* ======================================================================== */

/* vim: set ts=4 sts=4 sw=4 tw=80 et: */
/* EOF */
